==> python-boilerplate-tbcp-0.0.1.tar.gz: python-boilerplate-tbcp-0.0.1/README.md <==
<a href="https://bootcamp-project.com/" target="_blank"><img src="https://bootcamp-project.com/images/logo.png" align="right" height="200" /></a>

<h1 align="center">Python Package Boilerplate (with PyPi CI/CD)</h1>

<div align="center">
![security: bandit](https://img.shields.io/badge/security-bandit-yellow.svg?style=for-the-badge)
![PyPI](https://img.shields.io/pypi/v/dataanalyzing?style=for-the-badge)
![PyPI - Status](https://img.shields.io/pypi/status/dataanalyzing?style=for-the-badge)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/dataanalyzing?style=for-the-badge)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dataanalyzing?style=for-the-badge)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/dataanalyzing?style=for-the-badge)
![PyPI - License](https://img.shields.io/pypi/l/dataanalyzing?style=for-the-badge)
![Bootcamp Project: DataAnalyzing with Python](https://img.shields.io/badge/Bootcamp-Project-blue?style=for-the-badge)
</div>

## 👉 About 👈

**Minimum Viable Product**:

### 😎 Built With 😎

## 📖 Getting Started 📖

### ✋ Prerequisites ✋

### 💪 Installation 💪

```bash
python3 -m pip install --user *PACKAGE*
```

## 🚀 Usage 🚀

_For more examples, please refer to the [Documentation](https://dataanalyzing-python.rtfm.page)_

## ⭐️ Features ⭐️

## 📑 Changelog 📑

## 📋 Roadmap 📋

See the [open issues](https://gitlab.com/the-bootcamp-project/packages/data-science/dataanalyzing-python/-/issues) for a list of proposed features (and known issues).

## 🤝 Contribute 🤝

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Please read the [contribution guidelines](docs/_media/code_of_conduct.md) first.
2. Fork the Project
3. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
4. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
5. Push to the Branch (`git push origin feature/AmazingFeature`)
6. Open a Pull Request

## 📜 License 📜

Distributed under the MIT License. See [LICENSE](LICENSE) for more information.

## 💌 Contact 💌

[Bootcamp contributors](https://bootcamp-project.com/) - `contributors` @ `bootcamp-project` .com

## 🏆 Acknowledgements 🏆

Thanks for these awesome resources that were used during the development of the **Bootcamp Project: DataAnalyzing with Python**:

- [pytest-dev/pytest](https://github.com/pytest-dev/pytest/)
- [PyCQA/pylint](https://github.com/PyCQA/pylint)
- [PyCQA/bandit](https://github.com/PyCQA/bandit)

==> python-boilerplate-tbcp-0.1.0.tar.gz: python-boilerplate-tbcp-0.1.0/README.md <==
<a href="https://bootcamp-project.com/" target="_blank"><img src="https://bootcamp-project.com/images/logo.png" align="right" height="200" /></a>

<h1 align="center">Python Package Boilerplate (with PyPi CI/CD)</h1>

<div align="center">
![security: bandit](https://img.shields.io/badge/security-bandit-yellow.svg?style=for-the-badge)
![PyPI](https://img.shields.io/pypi/v/dataanalyzing?style=for-the-badge)
![PyPI - Status](https://img.shields.io/pypi/status/dataanalyzing?style=for-the-badge)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/dataanalyzing?style=for-the-badge)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dataanalyzing?style=for-the-badge)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/dataanalyzing?style=for-the-badge)
![PyPI - License](https://img.shields.io/pypi/l/dataanalyzing?style=for-the-badge)
![Bootcamp Project: DataAnalyzing with Python](https://img.shields.io/badge/Bootcamp-Project-blue?style=for-the-badge)
</div>

## 👉 About 👈

**Minimum Viable Product**:

### 😎 Built With 😎

- [pytest-dev/pytest](https://github.com/pytest-dev/pytest/)
- [PyCQA/pylint](https://github.com/PyCQA/pylint)
- [PyCQA/bandit](https://github.com/PyCQA/bandit)
-
## 📖 Getting Started 📖

**Change the project-specific attributes.** See [TODO](TODO.md) for more information.

### ✋ Prerequisites ✋

### 💪 Installation 💪

```bash
python3 -m pip install --user *PACKAGE*
```

## 🚀 Usage 🚀

_For more examples, please refer to the [Documentation](https://python.rtfm.page)_

## ⭐️ Features ⭐️

## 📑 Changelog 📑

## 📋 Roadmap 📋

See the [open issues](https://gitlab.com/the-bootcamp-project/boilerplates/python-package/-/issues) for a list of proposed features (and known issues).

## 🤝 Contribute 🤝

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Please read the [contribution guidelines](docs/_media/code_of_conduct.md) first.
2. Fork the Project
3. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
4. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
5. Push to the Branch (`git push origin feature/AmazingFeature`)
6. Open a Pull Request

## 📜 License 📜

Distributed under the MIT License. See [LICENSE](LICENSE) for more information.

## 💌 Contact 💌

[Bootcamp contributors](https://bootcamp-project.com/) - `contributors` @ `bootcamp-project` .com

## 🏆 Acknowledgements 🏆

Thanks for these awesome resources that were used during the development of the **Bootcamp Project: Python Package Boilerplate**:
